pub fn format_tree(
entries: &[Entry],
colorizer: &Colorizer,
icons: bool,
indicator: IndicatorStyle,
) -> StringExpand description
Render a basic tree from a flat recursive listing (headers + entries with depth).
Also works for a single non-recursive directory by treating all entries as depth 0.